==> activity-center-api-1.2.6.5.5.jyc-20161025.104237-2-sources.jar: cn/com/duiba/activity/center/api/remoteservice/direct/RemoteDuibaActivityAppSpecifyNewService.java <==
package cn.com.duiba.activity.center.api.remoteservice.direct;

import cn.com.duiba.activity.center.api.dto.direct.DuibaActivityAppSpecifyNewDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

/**
 * Created by suyuanlong on 16/7/19.
 */
public interface RemoteDuibaActivityAppSpecifyNewService {


    /**
     * @param activityId
     * @param appId
     * @param activityType
     * @return
     */
    DubboResult<DuibaActivityAppSpecifyNewDto> findAppSpecifyByActivityIdAndAppIdAndActivityType(Long activityId, Long appId, String activityType);

    /**
     * @param activityId
     * @param type
     * @return
     */

    DubboResult<List<DuibaActivityAppSpecifyNewDto>> findAppSpecifyByActivityIdAndActivityType(Long activityId, String type);

    /**
     * @param specifyBto
     * @return id
     */

    DubboResult<Long> insertAppSpecify(DuibaActivityAppSpecifyNewDto specifyBto);

    /**
     * @param id
     * @return 0 1
     */
    DubboResult<Boolean> deleteAppSpecifyById(Long id);

    /***
     * @param id
     * @return
     */
    DubboResult<DuibaActivityAppSpecifyNewDto> findAppSpecifyById(Long id);

    /**
     * @param activityId
     * @param appId
     * @param activityType
     * @return
     */
    DubboResult<Boolean> isNotAppSpecifyByActivityIdAndAppIdAndActivityType(Long activityId, Long appId, String activityType);
    /**
     * @return 获取不是定向活动列表
     * @author zhujianda
     * 批量获取,减少dubbo交互
     */
    public DubboResult<List<Long>> notInappSpecifyActivitys(List<DuibaActivityAppSpecifyNewDto> paras);
}

==> activity-center-api-1.2.10.2-jyc-20161123.055756-1-sources.jar: cn/com/duiba/activity/center/api/remoteservice/direct/RemoteDuibaActivityAppSpecifyNewService.java <==
package cn.com.duiba.activity.center.api.remoteservice.direct;

import cn.com.duiba.activity.center.api.dto.direct.DuibaActivityAppSpecifyNewDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

/**
 * Created by suyuanlong on 16/7/19.
 */
public interface RemoteDuibaActivityAppSpecifyNewService {


    /**
     * 此方法在WEB端存在大量的循环调用(请相关部门优化)
     * 已经提供service层的优化方法:DuibaActivityAppSpecifyNewService.batchFindIsSpecifyActivityIds
     * @param activityId
     * @param appId
     * @param activityType
     * @return
     */
    DubboResult<DuibaActivityAppSpecifyNewDto> findAppSpecifyByActivityIdAndAppIdAndActivityType(Long activityId, Long appId, String activityType);

    /**
     * @param activityId
     * @param type
     * @return
     */

    DubboResult<List<DuibaActivityAppSpecifyNewDto>> findAppSpecifyByActivityIdAndActivityType(Long activityId, String type);

    /**
     * @param specifyBto
     * @return id
     */

    DubboResult insertAppSpecify(DuibaActivityAppSpecifyNewDto specifyBto);

    /**
     * @param id
     * @return 0 1
     */
    DubboResult<Boolean> deleteAppSpecifyById(Long id);

    /***
     * @param id
     * @return
     */
    DubboResult<DuibaActivityAppSpecifyNewDto> findAppSpecifyById(Long id);

    /**
     * @param activityId
     * @param appId
     * @param activityType
     * @return
     */
    DubboResult<Boolean> isNotAppSpecifyByActivityIdAndAppIdAndActivityType(Long activityId, Long appId, String activityType);
    /**
     * @return 获取不是定向活动列表
     * @author zhujianda
     * 批量获取,减少dubbo交互
     */
    public DubboResult<List<Long>> notInappSpecifyActivitys(List<DuibaActivityAppSpecifyNewDto> paras);
    
    /**
     * notInappSpecifyActivitys. <br/>
     * 方法同上，参数不同
     * @author wubo
     * @param activityIds
     * @param appId
     * @param activityType
     * @return List<Long> 不是定向活动的ids
     * @since JDK 1.6
     */
    DubboResult<List<Long>> notInappSpecifyActivitys(List<Long> activityIds,Long appId,String activityType);
    
    /**
     * inappSpecifyActivitys. <br/>
     * 方法同上，逻辑相反
     * @author wubo
     * @param activityIds
     * @param appId
     * @param activityType
     * @return List<Long> 是定向活动的ids
     * @since JDK 1.6
     */
    DubboResult<List<Long>> inappSpecifyActivitys(List<Long> activityIds,Long appId,String activityType);
}
